
import usb
import pygame
import math
import random

RQ_GET_STICK1 = 0
RQ_GET_STICK2 = 1
RQ_SET_LIGHT1 = 2
RQ_SET_LIGHT2 = 3
RQ_SET_BUZZ = 4

####################################
def find_mcu_boards():
    '''
    Find all Practicum MCU boards attached to the machine, then return a list
    of USB device handles for all the boards

    >>> devices = find_mcu_boards()
    >>> first_board = McuBoard(devices[0])
    '''
    boards = [dev for bus in usb.busses()
                  for dev in bus.devices
                  if (dev.idVendor,dev.idProduct) == (0x16c0,0x05dc)]
    return boards

#####################################
class McuBoard:
    '''
    Generic class for accessing Practicum MCU board via USB connection.
    '''

    ################################
    def __init__(self, dev):
        self.device = dev
        self.handle = dev.open()

    ################################
    def usb_write(self, request, data=[], index=0, value=0):
        '''
        Send data output to the USB device (i.e., MCU board)
           request: request number to appear as bRequest field on the USB device
           index: 16-bit value to appear as wIndex field on the USB device
           value: 16-bit value to appear as wValue field on the USB device
        '''
        reqType = usb.TYPE_VENDOR | usb.RECIP_DEVICE | usb.ENDPOINT_OUT
        self.handle.controlMsg(
                reqType, request, data, value=value, index=index)

    ################################
    def usb_read(self, request, length=1, index=0, value=0):
        '''
        Request data input from the USB device (i.e., MCU board)
           request: request number to appear as bRequest field on the USB device
           length: number of bytes to read from the USB device
           index: 16-bit value to appear as wIndex field on the USB device
           value: 16-bit value to appear as wValue field on the USB device

        If successful, the method returns a tuple of length specified
        containing data returned from the MCU board.
        '''
        reqType = usb.TYPE_VENDOR | usb.RECIP_DEVICE | usb.ENDPOINT_IN
        buf = self.handle.controlMsg(
                reqType, request, length, value=value, index=index)
        return buf

####################################
class PeriBoard:

    ################################
    def __init__(self, mcu):
        self.mcu = mcu

    ################################
    def get_stick1(self):
	state = self.mcu.usb_read(request=RQ_GET_STICK1, length=1)
	return state[0] == 1

    ################################
    def get_stick2(self):
        state = self.mcu.usb_read(request=RQ_GET_STICK2, length=1)
        return state[0] == 1

    ################################



# Initialize
pygame.init()

# create the screen ( Wide Height)
screen = pygame.display.set_mode((1024, 768))

# Plane game player
playerImg = pygame.image.load("plane.png")
playerX = 576
playerY = 192
playerX_change = 0
playerY_change = 0
playerSpeed = 0.3

# Plane game Gold  // with random coordinate
goldImg = pygame.image.load("drop.png")
goldX = random.randint(530, 960)
goldY = random.randint(10, 300)


def collide(px, py, gx, gy):
    distance = math.sqrt((math.pow(px-gx, 2)) + (math.pow(py-gy, 2)))
    if distance < 27:
        return True
    else:
        return False


def player(screen, x, y):
    screen.blit(playerImg, (x, y))


def gold(screen, x, y):
    screen.blit(goldImg, (x, y))


# Jump game player
cactusImg = pygame.image.load("aircraft2.png")
cactusX = 70
cactusY = 400
cactusY_change = +0.1
controlling = True


def cactus(screen, x, y):
    screen.blit(cactusImg, (x, y))


def building_collide(px, py, ex, ey):
    return 0

# Dodge da missile player


frontImg = pygame.image.load("aircraft_front.png")
frontX = 200
frontY = 50
frontX_change = 0


def front(screen, x, y):
    screen.blit(frontImg, (x, y))


missileImg = pygame.image.load("missile_up.png")
missileX = random.randint(20, 450)
missileY = 300


def missile(screen, x, y):
    screen.blit(missileImg, (x, y))


building1Img = pygame.image.load("drawing.png").convert()
buildingX = 1100
buildingY = random.randint(500, 700)
building2X = 1500
building2Y = random.randint(500, 700)


def B1(screen, x, y):
    screen.blit(building1Img, (x, y))
